@@ -2,8 +2,8 @@ import datetime
 import logging
 import os
 import threading
-from logging.handlers import BufferingHandler
 from pathlib import Path
+from logging.handlers import BufferingHandler
 from types import MethodType
 
 from res.enkf import ErtScript
@@ -47,7 +47,7 @@ class _ReportHandler(BufferingHandler):
         )
 
 
-class SemeioScript(ErtScript):
+class SemeioScript(ErtScript):  # pylint: disable=too-few-public-methods
     """
     SemeioScript is a workflow utility extending the functionality of ErtScript.
     In particular it provides a `self.reporter` instance available for passing
@@ -76,12 +76,14 @@ class SemeioScript(ErtScript):
 
     def _get_output_dir(self):
         res_config = self.ert().resConfig()
-        base_dir = res_config.config_path
-        base_dir = os.path.realpath(base_dir)
-        sub_dir = Path(res_config.user_config_file).stem
+        base_dir = Path(res_config.model_config.getEnspath()).parent.absolute()
+        sub_dir = str(
+            self.ert().getEnkfFsManager().getCurrentFileSystem().getCaseName()
+        )
         return os.path.join(
             base_dir,
             "reports",
+            Path(res_config.user_config_file).stem,
             sub_dir,
             type(self).__name__,
         )
@@ -89,3 +91,17 @@ class SemeioScript(ErtScript):
     @property
     def reporter(self):
         return self._reporter
+
+    @property
+    def _reports_dir(self):
+        return self.reporter._output_dir
+
+    @_reports_dir.setter
+    def _reports_dir(self, output_dir):
+        output_dir = Path(output_dir)
+        if not output_dir.is_absolute():
+            res_config = self.ert().resConfig()
+            base_dir = Path(res_config.model_config.getEnspath()).parent.absolute()
+            self.reporter._output_dir = base_dir / output_dir
+        else:
+            self.reporter._output_dir = output_dir
