@@ -40,9 +40,11 @@ observations during the history matching process in ERT.
 
 Results will be exported in csv files which can be used in Webviz to perform
 analysis of the AHM through the AhmAnalysis plugin. CSV files will be stored
-under a folder named :code:`ert/output/storage/reports/prior_name/AhmAnalysisJob/`.
+under a folder named :code:`ENSPATH/../reports/prior_name/AhmAnalysisJob/`.
 prior_name will be the name of the case selected in current case on the ERT GUI
-(often :code:`default`)or given as optional input to the workflow. Files generated are:
+(often :code:`default`)or given as optional input to the workflow. Note that
+depending on the setup of ENSPATH, files may be overwritten when the workflow
+is run for different ert cases. Files generated are:
 
  - One csv file per observation group with posterior distribution of the
    different parameters for each observation group included in the update.
@@ -117,9 +119,17 @@ class AhmAnalysisJob(SemeioScript):  # pylint: disable=too-few-public-methods
     observation during history matching
     """
 
-    def run(self, target_name="analysis_case", prior_name=None, group_by="data_key"):
+    def run(
+        self,
+        target_name="analysis_case",
+        prior_name=None,
+        group_by="data_key",
+        output_dir=None,
+    ):
         """Perform analysis of parameters change per obs group
         prior to posterior of ahm"""
+        if output_dir is not None:
+            self._reports_dir = output_dir
         ert = self.ert()
         facade = LibresFacade(self.ert())
 
@@ -438,7 +448,7 @@ def calc_observationsgroup_misfit(obs_keys, df_update_log, misfit_df):
         mean = (
             misfit_df[df_misfit_calc["Misfit_key"].to_list()].sum(axis=1) / total_obs_nr
         )
-    return mean.loc[0]
+    return mean.mean()
 
 
 def load_grid_to_dataframe(grid_path):
