@@ -1,9 +1,10 @@
 import yaml
-import configsuite
 
 from ert_data.measured import MeasuredData
 from ert_shared.libres_facade import LibresFacade
 from ert_shared.plugins.plugin_manager import hook_implementation
+
+from semeio._docs_utils._json_schema_2_rst import _create_docs
 from semeio.communication import SemeioScript
 
 from semeio.workflows.misfit_preprocessor.config import assemble_config
@@ -14,6 +15,7 @@ from semeio.workflows.correlated_observations_scaling.cos import (
 from semeio.workflows.correlated_observations_scaling.exceptions import (
     EmptyDatasetException,
 )
+from semeio.workflows.misfit_preprocessor.workflow_config import MisfitConfig
 
 
 class MisfitPreprocessorJob(SemeioScript):
@@ -22,8 +24,8 @@ class MisfitPreprocessorJob(SemeioScript):
         config_record = _fetch_config_record(args)
         observations = _get_observations(facade)
         config = assemble_config(config_record, observations)
-        config = config.snapshot
-
+        if config.reports_directory:
+            self._reports_dir = config.reports_directory
         measured_record = _load_measured_record(facade, config.observations)
         scaling_configs = misfit_preprocessor.run(
             **{
@@ -36,9 +38,6 @@ class MisfitPreprocessorJob(SemeioScript):
         # The execution of COS should be moved into
         # misfit_preprocessor.run when COS no longer depend on self.ert
         # to run.
-        scaling_params = _fetch_scaling_parameters(config_record, observations)
-        for scaling_config in scaling_configs:
-            scaling_config["CALCULATE_KEYS"].update(scaling_params)
 
         try:
             CorrelatedObservationsScalingJob(self.ert()).run(scaling_configs)
@@ -46,22 +45,6 @@ class MisfitPreprocessorJob(SemeioScript):
             pass
 
 
-def _fetch_scaling_parameters(config_record, observations):
-    config = misfit_preprocessor.assemble_config(
-        config_record,
-        observations,
-    )
-    if not config.valid:
-        # The config is loaded by misfit_preprocessor.run first. The
-        # second time should never fail!
-        raise ValueError("Misfit preprocessor config not valid on second load")
-
-    scale_conf = config.snapshot.scaling
-    return {
-        "threshold": scale_conf.threshold,
-    }
-
-
 def _fetch_config_record(args):
     if len(args) == 0:
         return {}
@@ -92,10 +75,28 @@ def _get_observations(facade):
     ]
 
 
+def _get_example(config_example):
+    example_string = yaml.dump(config_example, default_flow_style=False)
+    return "\n      ".join(example_string.split("\n"))
+
+
+_INTERIM_DESCRIPTION = f"""
+\n\nThe MisfitPreprocessor configuration is currently changing, and will be updated
+shortly. It is advised to just run the MISFIT_PREPROCESSOR without a config to
+get the default behavior, or a config with just a list of observations under
+the observations keyword.
+
+
+.. code-block:: yaml
+
+    {_get_example({"observations": ["FOPR", "W*"]})}
+
+"""
+
+
 @hook_implementation
 def legacy_ertscript_workflow(config):
     workflow = config.add_workflow(MisfitPreprocessorJob, "MISFIT_PREPROCESSOR")
-    _schema = misfit_preprocessor.config._SCHEMA
-    rst_doc = configsuite.docs.generate(_schema)
-    workflow.description = rst_doc
+    schema = MisfitConfig().schema(by_alias=False, ref_template="{model}")
+    workflow.description = _create_docs(schema)
     workflow.category = "observations.correlation"
