@@ -9,18 +9,22 @@ from semeio.communication import SEMEIOSCRIPT_LOG_FILE, SemeioScript
 from unittest.mock import Mock
 
 
-def _ert_mock(config_path="config_path", user_config_file="config_file"):
+def _ert_mock(ensemble_path="storage", user_case_name="case_name"):
     resconfig_mock = Mock()
-    resconfig_mock.config_path = config_path
-    resconfig_mock.user_config_file = user_config_file
-
-    return Mock(resConfig=Mock(return_value=resconfig_mock))
+    resconfig_mock.model_config.getEnspath.return_value = ensemble_path
+    resconfig_mock.user_config_file = "config_name.ert"
+    ert_mock = Mock()
+    fs_mock = Mock()
+    fs_mock.return_value.getCaseName.return_value = user_case_name
+    ert_mock.getEnkfFsManager.return_value.getCurrentFileSystem = fs_mock
+    ert_mock.resConfig.return_value = resconfig_mock
+    return ert_mock
 
 
 def test_semeio_script_publish(tmpdir):
     tmpdir.chdir()
-    config_path, user_config_file = "config_path", "config_file"
-    ert = _ert_mock(config_path, user_config_file)
+    ensemble_path, user_case_name = "storage", "case_name"
+    ert = _ert_mock(ensemble_path, user_case_name)
 
     namespace = "arbitrary_data"
     data = [1, 2, 3, 4, "This is a very important string"]
@@ -33,9 +37,9 @@ def test_semeio_script_publish(tmpdir):
     my_super_script.run()
 
     expected_outputfile = os.path.join(
-        config_path,
         "reports",
-        user_config_file,
+        "config_name",
+        user_case_name,
         MySuperScript.__name__,
         namespace + ".json",
     )
@@ -48,8 +52,8 @@ def test_semeio_script_publish(tmpdir):
 
 def test_semeio_script_logging(tmpdir):
     tmpdir.chdir()
-    config_path, user_config_file = "config_path", "config_file"
-    ert = _ert_mock(config_path, user_config_file)
+    ensemble_path, user_case_name = "storage", "config_file"
+    ert = _ert_mock(ensemble_path, user_case_name)
 
     msg = "My logging msg"
 
@@ -61,9 +65,9 @@ def test_semeio_script_logging(tmpdir):
     my_super_script.run()
 
     expected_logfile = os.path.join(
-        config_path,
         "reports",
-        user_config_file,
+        "config_name",
+        user_case_name,
         MySuperScript.__name__,
         SEMEIOSCRIPT_LOG_FILE,
     )
@@ -94,8 +98,8 @@ def assert_log(messages, log_file):
 )
 def test_semeio_script_multiple_logging(messages, tmpdir):
     tmpdir.chdir()
-    config_path, user_config_file = "config_path", "config_file"
-    ert = _ert_mock(config_path, user_config_file)
+    ensemble_path, user_case_name = "storage", "config_file"
+    ert = _ert_mock(ensemble_path, user_case_name)
 
     class MySuperScript(SemeioScript):
         def run(self, *args):
@@ -107,9 +111,9 @@ def test_semeio_script_multiple_logging(messages, tmpdir):
                 assert_log(posted_messages, expected_logfile)
 
     expected_logfile = os.path.join(
-        config_path,
         "reports",
-        user_config_file,
+        "config_name",
+        user_case_name,
         MySuperScript.__name__,
         SEMEIOSCRIPT_LOG_FILE,
     )
@@ -122,8 +126,8 @@ def test_semeio_script_multiple_logging(messages, tmpdir):
 
 def test_semeio_script_post_logging(tmpdir):
     tmpdir.chdir()
-    config_path, user_config_file = "config_path", "config_file"
-    ert = _ert_mock(config_path, user_config_file)
+    ensemble_path, user_case_name = "storage", "config_file"
+    ert = _ert_mock(ensemble_path, user_case_name)
 
     class MySuperScript(SemeioScript):
         def run(self, *args):
@@ -135,9 +139,9 @@ def test_semeio_script_post_logging(tmpdir):
     logging.error("A second message - not from MySuperScript")
 
     expected_logfile = os.path.join(
-        config_path,
         "reports",
-        user_config_file,
+        "config_name",
+        user_case_name,
         MySuperScript.__name__,
         SEMEIOSCRIPT_LOG_FILE,
     )
@@ -150,8 +154,8 @@ def test_semeio_script_post_logging(tmpdir):
 
 def test_semeio_script_pre_logging(tmpdir):
     tmpdir.chdir()
-    config_path, user_config_file = "config_path", "config_file"
-    ert = _ert_mock(config_path, user_config_file)
+    ensemble_path, user_case_name = "storage", "config_file"
+    ert = _ert_mock(ensemble_path, user_case_name)
 
     class MySuperScript(SemeioScript):
         def run(self, *args):
@@ -164,9 +168,9 @@ def test_semeio_script_pre_logging(tmpdir):
     my_super_script.run()
 
     expected_logfile = os.path.join(
-        config_path,
         "reports",
-        user_config_file,
+        "config_name",
+        user_case_name,
         MySuperScript.__name__,
         SEMEIOSCRIPT_LOG_FILE,
     )
@@ -179,8 +183,8 @@ def test_semeio_script_pre_logging(tmpdir):
 
 def test_semeio_script_concurrent_logging(tmpdir):
     tmpdir.chdir()
-    config_path, user_config_file = "config_path", "config_file"
-    ert = _ert_mock(config_path, user_config_file)
+    ensemble_path, user_case_name = "storage", "config_file"
+    ert = _ert_mock(ensemble_path, user_case_name)
 
     class MySuperScript(SemeioScript):
         def run(self, *args):
@@ -192,9 +196,9 @@ def test_semeio_script_concurrent_logging(tmpdir):
     MySuperScript(ert).run()
 
     expected_logfile = os.path.join(
-        config_path,
         "reports",
-        user_config_file,
+        "config_name",
+        user_case_name,
         MySuperScript.__name__,
         SEMEIOSCRIPT_LOG_FILE,
     )
@@ -207,8 +211,8 @@ def test_semeio_script_concurrent_logging(tmpdir):
 
 def test_semeio_script_post_logging_exception(tmpdir):
     tmpdir.chdir()
-    config_path, user_config_file = "config_path", "config_file"
-    ert = _ert_mock(config_path, user_config_file)
+    ensemble_path, user_case_name = "storage", "config_file"
+    ert = _ert_mock(ensemble_path, user_case_name)
 
     class MySuperScript(SemeioScript):
         def run(self, *args):
@@ -224,9 +228,9 @@ def test_semeio_script_post_logging_exception(tmpdir):
     logging.error("A second message - not from MySuperScript")
 
     expected_logfile = os.path.join(
-        config_path,
         "reports",
-        user_config_file,
+        "config_name",
+        user_case_name,
         MySuperScript.__name__,
         SEMEIOSCRIPT_LOG_FILE,
     )
@@ -239,8 +243,8 @@ def test_semeio_script_post_logging_exception(tmpdir):
 
 def test_semeio_script_keyword_args(tmpdir):
     tmpdir.chdir()
-    config_path, user_config_file = "config_path", "config_file"
-    ert = _ert_mock(config_path, user_config_file)
+    ensemble_path, user_case_name = "storage", "config_file"
+    ert = _ert_mock(ensemble_path, user_case_name)
 
     class MySuperScript(SemeioScript):
         def run(self, param_A, param_B):
@@ -251,9 +255,9 @@ def test_semeio_script_keyword_args(tmpdir):
     my_super_script.run(param_B="param_B", param_A="param_A")
 
     expected_outputfile = os.path.join(
-        config_path,
         "reports",
-        user_config_file,
+        "config_name",
+        user_case_name,
         MySuperScript.__name__,
         SEMEIOSCRIPT_LOG_FILE,
     )
@@ -262,3 +266,69 @@ def test_semeio_script_keyword_args(tmpdir):
         published_msgs = f.readlines()
     assert published_msgs[0] == "param_A\n"
     assert published_msgs[1] == "param_B\n"
+
+
+def test_semeio_script_relative_report_dir(tmpdir):
+    tmpdir.chdir()
+    ensemble_path, user_case_name = "storage", "config_file"
+    ert = _ert_mock(ensemble_path, user_case_name)
+
+    class MySuperScript(SemeioScript):
+        def run(self, param_A):
+            self._reports_dir = "a_new_subdir"
+            self.reporter.publish_msg(SEMEIOSCRIPT_LOG_FILE, param_A)
+
+    my_super_script = MySuperScript(ert)
+    my_super_script.run(param_A="param_A")
+
+    expected_outputfile = os.path.join(
+        "a_new_subdir",
+        SEMEIOSCRIPT_LOG_FILE,
+    )
+    with open(expected_outputfile) as f:
+        published_msgs = f.readlines()
+    assert published_msgs[0] == "param_A\n"
+
+
+def test_semeio_script_absolute_report_dir(tmpdir):
+    ensemble_path, user_case_name = "storage", "config_file"
+    ert = _ert_mock(ensemble_path, user_case_name)
+
+    class MySuperScript(SemeioScript):
+        def run(self, param_A):
+            self._reports_dir = tmpdir
+            self.reporter.publish_msg(SEMEIOSCRIPT_LOG_FILE, param_A)
+
+    my_super_script = MySuperScript(ert)
+    my_super_script.run(param_A="param_A")
+
+    expected_outputfile = os.path.join(
+        tmpdir,
+        SEMEIOSCRIPT_LOG_FILE,
+    )
+    with open(expected_outputfile) as f:
+        published_msgs = f.readlines()
+    assert published_msgs[0] == "param_A\n"
+
+
+def test_semeio_script_subdirs(tmpdir):
+    ensemble_path, user_case_name = "storage", "config_file"
+    ert = _ert_mock(ensemble_path, user_case_name)
+
+    class MySuperScript(SemeioScript):
+        def run(self, param_A):
+            self._reports_dir = os.path.join(tmpdir, "sub_dir_1", "sub_dir_2")
+            self.reporter.publish_msg(SEMEIOSCRIPT_LOG_FILE, param_A)
+
+    my_super_script = MySuperScript(ert)
+    my_super_script.run(param_A="param_A")
+
+    expected_outputfile = os.path.join(
+        tmpdir,
+        "sub_dir_1",
+        "sub_dir_2",
+        SEMEIOSCRIPT_LOG_FILE,
+    )
+    with open(expected_outputfile) as f:
+        published_msgs = f.readlines()
+    assert published_msgs[0] == "param_A\n"
