@@ -1,8 +1,9 @@
+# pylint: disable=unsubscriptable-object  # pylint issue
 import os
 import shutil
 import pytest
 import pandas as pd
-import semeio.workflows.ahm_analysis.ahmanalysis as ahmanalysis
+from semeio.workflows.ahm_analysis import ahmanalysis
 from semeio._exceptions.exceptions import ValidationError
 
 from pathlib import Path
@@ -29,7 +30,7 @@ def test_ahmanalysis_run(test_data_root):
     ahmanalysis.AhmAnalysisJob(ert).run(prior_name="default_0")
 
     # assert that this returns/generates a KS csv file
-    output_dir = Path("storage/snake_oil/reports/default_0/AhmAnalysisJob")
+    output_dir = Path("storage/snake_oil/reports/snake_oil/default_0/AhmAnalysisJob")
     group_obs = [
         "FOPR",
         "WOPR_OP1",
@@ -93,6 +94,7 @@ def test_ahmanalysis_run_field(test_data_root, grid_prop):
         "storage",
         "snake_oil_field",
         "reports",
+        "snake_oil_field",
         "default",
         "AhmAnalysisJob",
         "delta_fieldPERMX.csv",
