@@ -10,7 +10,7 @@ from semeio.workflows.correlated_observations_scaling import cos
 from semeio.workflows.correlated_observations_scaling.cos import (
     CorrelatedObservationsScalingJob,
 )
-from tests.jobs.correlated_observations_scaling.conftest import TEST_DATA_DIR
+from tests.jobs.conftest import TEST_DATA_DIR
 from ert_shared.plugins.plugin_manager import ErtPluginManager
 from unittest.mock import MagicMock
 
@@ -26,7 +26,6 @@ def assert_obs_vector(vector, val_1, index_list=None, val_2=None):
                 assert node.getStdScaling(index) == val_1
 
 
-@pytest.mark.usefixtures("setup_ert")
 def test_old_enkf_scaling_job(setup_ert):
     res_config = setup_ert
     ert = EnKFMain(res_config)
@@ -42,7 +41,6 @@ def test_old_enkf_scaling_job(setup_ert):
     assert_obs_vector(obs_vector, np.sqrt(4.0 / 2.0))
 
 
-@pytest.mark.usefixtures("setup_ert")
 def test_installed_python_version_of_enkf_scaling_job(setup_ert, monkeypatch):
 
     pm = ErtPluginManager(
@@ -88,16 +86,10 @@ def test_installed_python_version_of_enkf_scaling_job(setup_ert, monkeypatch):
     )
 
 
-@pytest.mark.usefixtures("setup_tmpdir")
-def test_compare_different_jobs(test_data_root):
+def test_compare_different_jobs(setup_ert):
     cos_config = {"CALCULATE_KEYS": {"keys": [{"key": "WPR_DIFF_1"}]}}
 
-    test_data_dir = os.path.join(test_data_root, "snake_oil")
-
-    shutil.copytree(test_data_dir, "test_data")
-    os.chdir(os.path.join("test_data"))
-
-    res_config = ResConfig("snake_oil.ert")
+    res_config = setup_ert
 
     ert = EnKFMain(res_config)
     obs = ert.getObservations()
@@ -117,20 +109,12 @@ def test_compare_different_jobs(test_data_root):
     assert_obs_vector(obs_vector, np.sqrt(4 / 2))
 
 
-@pytest.mark.usefixtures("setup_tmpdir")
-def test_main_entry_point_gen_data(test_data_root):
+def test_main_entry_point_gen_data(setup_ert):
     cos_config = {
         "CALCULATE_KEYS": {"keys": [{"key": "WPR_DIFF_1"}]},
         "UPDATE_KEYS": {"keys": [{"key": "WPR_DIFF_1", "index": [400, 800]}]},
     }
-
-    test_data_dir = os.path.join(test_data_root, "snake_oil")
-
-    shutil.copytree(test_data_dir, "test_data")
-    os.chdir(os.path.join("test_data"))
-
-    res_config = ResConfig("snake_oil.ert")
-
+    res_config = setup_ert
     ert = EnKFMain(res_config)
 
     CorrelatedObservationsScalingJob(ert).run(cos_config)
@@ -150,7 +134,15 @@ def test_main_entry_point_gen_data(test_data_root):
         np.sqrt(3.0 / 2.0),
     )
 
-    svd_file = "reports/snake_oil/CorrelatedObservationsScalingJob/svd.json"
+    svd_file = os.path.join(
+        "storage",  # ens_path == storage/snake_oil/ensemble
+        "snake_oil",
+        "reports",
+        "snake_oil",
+        "default_0",
+        "CorrelatedObservationsScalingJob",
+        "svd.json",
+    )
     # Assert that data was published correctly
     with open(svd_file) as f:
         svd_reports = json.load(f)
@@ -166,7 +158,15 @@ def test_main_entry_point_gen_data(test_data_root):
             0.1,
         )
 
-    scale_file = "reports/snake_oil/CorrelatedObservationsScalingJob/scale_factor.json"
+    scale_file = os.path.join(
+        "storage",  # ens_path == storage/snake_oil/ensemble
+        "snake_oil",
+        "reports",
+        "snake_oil",
+        "default_0",
+        "CorrelatedObservationsScalingJob",
+        "scale_factor.json",
+    )
     with open(scale_file) as f:
         scalefactor_reports = json.load(f)
         assert len(scalefactor_reports) == 2
@@ -175,18 +175,12 @@ def test_main_entry_point_gen_data(test_data_root):
         assert reported_scalefactor == pytest.approx(1.224744871391589, 0.1)
 
 
-@pytest.mark.usefixtures("setup_tmpdir")
-def test_main_entry_point_summary_data_calc(test_data_root):
+def test_main_entry_point_summary_data_calc(setup_ert, monkeypatch):
     cos_config = {
         "CALCULATE_KEYS": {"keys": [{"key": "WOPR_OP1_108"}, {"key": "WOPR_OP1_144"}]}
     }
 
-    test_data_dir = os.path.join(test_data_root, "snake_oil")
-
-    shutil.copytree(test_data_dir, "test_data")
-    os.chdir(os.path.join("test_data"))
-
-    res_config = ResConfig("snake_oil.ert")
+    res_config = setup_ert
 
     ert = EnKFMain(res_config)
     obs = ert.getObservations()
@@ -199,7 +193,7 @@ def test_main_entry_point_summary_data_calc(test_data_root):
     CorrelatedObservationsScalingJob(ert).run(cos_config)
 
     for index, node in enumerate(obs_vector):
-        assert node.getStdScaling(index) == np.sqrt(1.0)
+        assert node.getStdScaling(index) == 1.0
 
 
 @pytest.mark.skipif(TEST_DATA_DIR is None, reason="no equinor libres test-data")
@@ -289,17 +283,10 @@ def test_main_entry_point_block_and_summary_data_calc():
         assert node.getStdScaling(index) == np.sqrt(64)
 
 
-@pytest.mark.usefixtures("setup_tmpdir")
-def test_main_entry_point_sum_data_update(test_data_root, monkeypatch):
+def test_main_entry_point_sum_data_update(setup_ert, monkeypatch):
     cos_config = {"CALCULATE_KEYS": {"keys": [{"key": "WOPR_OP1_108"}]}}
 
-    test_data_dir = os.path.join(test_data_root, "snake_oil")
-
-    shutil.copytree(test_data_dir, "test_data")
-    os.chdir(os.path.join("test_data"))
-
-    res_config = ResConfig("snake_oil.ert")
-
+    res_config = setup_ert
     ert = EnKFMain(res_config)
     obs = ert.getObservations()
 
@@ -314,3 +301,29 @@ def test_main_entry_point_sum_data_update(test_data_root, monkeypatch):
 
     for index, node in enumerate(obs_vector):
         assert node.getStdScaling(index) == 1.23
+
+
+def test_main_entry_point_shielded_data(setup_ert, monkeypatch):
+    cos_config = {
+        "CALCULATE_KEYS": {"keys": [{"key": "FOPR", "index": [1, 2, 3, 4, 5]}]}
+    }
+
+    res_config = setup_ert
+    ert = EnKFMain(res_config)
+    obs = ert.getObservations()
+
+    obs_vector = obs["FOPR"]
+
+    for index, node in enumerate(obs_vector):
+        assert node.getStdScaling(index) == 1.0
+
+    monkeypatch.setattr(
+        cos.ObservationScaleFactor, "get_scaling_factor", MagicMock(return_value=1.23)
+    )
+    CorrelatedObservationsScalingJob(ert).run(cos_config)
+
+    for index, node in enumerate(obs_vector):
+        if index in [1, 2, 3, 4, 5]:
+            assert node.getStdScaling(index) == 1.23, f"index: {index}"
+        else:
+            assert node.getStdScaling(index) == 1.0, f"index: {index}"
