@@ -1,13 +1,6 @@
-import sys
-
 import pytest
 
-from semeio.jobs.correlated_observations_scaling import validator
-
-if sys.version_info >= (3, 3):
-    from unittest.mock import Mock
-else:
-    from mock import Mock  # noqa
+from semeio.workflows.correlated_observations_scaling import validator
 
 
 @pytest.mark.parametrize(
