@@ -40,6 +40,7 @@ def ert_statoil_test_data(tmpdir):
     yield
 
     os.chdir(cwd)
+    tmpdir.remove()
 
 
 def mock_norne_data(reals, iters, parameters=True):
@@ -74,6 +75,9 @@ def mock_norne_data(reals, iters, parameters=True):
             if parameters:
                 with open(os.path.join(runpath, "parameters.txt"), "w") as p_fileh:
                     p_fileh.write("FOO 1{}{}".format(real, iteration))
+            # Ensure fmu-ensemble does not complain on missing STATUS
+            with open(os.path.join(runpath, "STATUS"), "w") as file_h:
+                file_h.write("a:b\na: 09:00:00 .... 09:00:01")
 
     with open("runpathfile", "w") as file_h:
         for iteration in iters:
