@@ -6,7 +6,7 @@ import pytest
 from res.enkf import EnKFMain, ResConfig
 
 import semeio
-import semeio.workflows.misfit_preprocessor.misfit_preprocessor as misfit_preprocessor
+from semeio.workflows.misfit_preprocessor import misfit_preprocessor
 from semeio.workflows.correlated_observations_scaling.exceptions import (
     EmptyDatasetException,
 )
@@ -16,7 +16,7 @@ from unittest.mock import Mock
 
 @pytest.mark.usefixtures("setup_tmpdir")
 @pytest.mark.parametrize(
-    "observation, expected_nr_clusters", [["*", 58], ["WPR_DIFF_1", 1]]
+    "observation, expected_nr_clusters", [["*", 60], ["WPR_DIFF_1", 1]]
 )
 def test_misfit_preprocessor_main_entry_point_gen_data(
     monkeypatch, test_data_root, observation, expected_nr_clusters
@@ -39,9 +39,9 @@ def test_misfit_preprocessor_main_entry_point_gen_data(
 
     config = {
         "observations": [observation],
-        "clustering": {
-            "method": "spearman_correlation",
-            "spearman_correlation": {"fcluster": {"t": 1.0}},
+        "workflow": {
+            "type": "custom_scale",
+            "clustering": {"fcluster": {"threshold": 1.0}},
         },
     }
     config_file = "my_config_file.yaml"
@@ -79,9 +79,12 @@ def test_misfit_preprocessor_passing_scaling_parameters(monkeypatch, test_data_r
     ert = EnKFMain(res_config)
 
     config = {
-        "clustering": {"method": "spearman_correlation"},
-        "scaling": {"threshold": 0.5, "std_cutoff": 2, "alpha": 3},
+        "workflow": {
+            "type": "custom_scale",
+            "pca": {"threshold": 0.5},
+        },
     }
+
     config_file = "my_config_file.yaml"
     with open(config_file, "w") as f:
         yaml.dump(config, f)
@@ -126,9 +129,11 @@ def test_misfit_preprocessor_with_scaling(test_data_root):
     ert = EnKFMain(res_config)
 
     config = {
-        "clustering": {
-            "method": "spearman_correlation",
-            "spearman_correlation": {"fcluster": {"t": 1.0}},
+        "workflow": {
+            "type": "custom_scale",
+            "clustering": {
+                "fcluster": {"threshold": 1.0},
+            },
         }
     }
     config_file = "my_config_file.yaml"
@@ -142,6 +147,9 @@ def test_misfit_preprocessor_with_scaling(test_data_root):
     for index in [13, 14, 15, 16, 17, 18, 19, 20]:
         assert obs.getNode(index).getStdScaling() == 2.8284271247461903
 
+    for index in (38, 39, 40, 41, 42, 43, 44):
+        assert obs.getNode(index).getStdScaling() == 2.6457513110645907
+
 
 @pytest.mark.usefixtures("setup_tmpdir")
 def test_misfit_preprocessor_skip_clusters_yielding_empty_data_matrixes(
@@ -165,10 +173,10 @@ def test_misfit_preprocessor_skip_clusters_yielding_empty_data_matrixes(
     ert = EnKFMain(res_config)
 
     config = {
-        "clustering": {
-            "method": "spearman_correlation",
-            "spearman_correlation": {"fcluster": {"t": 1.0}},
-        }
+        "workflow": {
+            "type": "custom_scale",
+            "clustering": {"fcluster": {"threshold": 1.0}},
+        },
     }
     config_file = "my_config_file.yaml"
     with open(config_file, "w") as f:
@@ -194,22 +202,60 @@ def test_misfit_preprocessor_invalid_config(test_data_root):
 
     config = {
         "unknown_key": [],
-        "clustering": {
-            "method": "spearman_correlation",
-            "spearman_correlation": {"fcluster": {"threshold": 1.0}},
-        },
+        "workflow": {"type": "custom_scale", "clustering": {"threshold": 1.0}},
     }
     config_file = "my_config_file.yaml"
     with open(config_file, "w") as f:
         yaml.dump(config, f)
 
-    job = misfit_preprocessor.MisfitPreprocessorJob(ert)
-    with pytest.raises(semeio.workflows.misfit_preprocessor.ValidationError) as ve:
-        job.run(config_file)
-
     expected_err_msg = (
         "Invalid configuration of misfit preprocessor\n"
-        "  - Unknown key: unknown_key (root level)\n"
-        "  - Unknown key: threshold (clustering.spearman_correlation.fcluster)\n"
+        "  - extra fields not permitted (workflow.clustering.threshold)\n"
+        # There are two clustering functions, and this is invalid in both
+        "  - extra fields not permitted (workflow.clustering.threshold)\n"
+        "  - extra fields not permitted (unknown_key)\n"
     )
-    assert expected_err_msg == str(ve.value)
+    job = misfit_preprocessor.MisfitPreprocessorJob(ert)
+    with pytest.raises(semeio.workflows.misfit_preprocessor.ValidationError) as err:
+        job.run(config_file)
+    assert str(err.value) == expected_err_msg
+
+
+@pytest.mark.usefixtures("setup_tmpdir")
+def test_misfit_preprocessor_all_obs(test_data_root, monkeypatch):
+    from unittest.mock import MagicMock
+    from semeio.workflows.correlated_observations_scaling import cos
+
+    test_data_dir = os.path.join(test_data_root, "snake_oil")
+
+    shutil.copytree(test_data_dir, "test_data")
+    os.chdir(os.path.join("test_data"))
+
+    res_config = ResConfig("snake_oil.ert")
+    ert = EnKFMain(res_config)
+
+    monkeypatch.setattr(
+        cos.ObservationScaleFactor, "get_scaling_factor", MagicMock(return_value=1.234)
+    )
+
+    misfit_preprocessor.MisfitPreprocessorJob(ert).run()
+
+    scaling_factors = []
+
+    obs = ert.getObservations()
+    for key in [
+        "FOPR",
+        "WOPR_OP1_9",
+        "WOPR_OP1_36",
+        "WOPR_OP1_72",
+        "WOPR_OP1_108",
+        "WOPR_OP1_144",
+        "WOPR_OP1_190",
+        "WPR_DIFF_1",
+    ]:
+        obs_vector = obs[key]
+        for index, node in enumerate(obs_vector):
+            scaling_factors.append((index, key, node.getStdScaling(index)))
+
+    for index, key, scaling_factor in scaling_factors:
+        assert scaling_factor == 1.234, f"{index}, {key}"
