@@ -1,5 +1,5 @@
 import itertools
-import argparse
+from pathlib import Path
 
 import pandas as pd
 
@@ -30,9 +30,8 @@ def test_load_from_line(line, expected_zone):
     ],
 )
 def test_invalid_load_from_line(line, expected_error):
-    with pytest.raises(argparse.ArgumentTypeError) as err_context:
+    with pytest.raises(ValueError, match=expected_error):
         TrajectoryPoint(*Trajectory.parse_trajectory_line(line))
-    assert expected_error in err_context.value.args[0]
 
 
 @pytest.mark.parametrize(
@@ -119,10 +118,11 @@ def test_dframe_trajectory(initdir, fname):
 
     # Dataframe lengths should be the same as number of non-empty lines
     # in txt input:
+
     assert len(dframe) == len(
         [
             line
-            for line in open(fname).readlines()
+            for line in Path(fname).read_text().split("\n")
             if line.strip() and not line.strip().startswith("--")
         ],
     )
@@ -245,9 +245,5 @@ def test_tuple_column_splitter_explicit():
 
 def test_non_existing_file():
 
-    with pytest.raises(argparse.ArgumentTypeError) as err_context:
+    with pytest.raises(IOError, match="Trajectory file non_existing not found!"):
         Trajectory.load_from_file("non_existing")
-
-    assert (
-        "Warning: Trajectory file non_existing not found!" == err_context.value.args[0]
-    )
